@@ -39,6 +39,7 @@ class BeaconAPI(object):
     version = 'v1'
     section = 'main'    # name of section in INI file we are using
     keySource = None
+    timeout = None
 
     def __init__(self, host=None, key=None):
         self.host, self.key = host, key
@@ -158,7 +159,7 @@ class BeaconAPI(object):
         else:
             return {"x-apikey" : self.key}
 
-    def do(self, action, name, args):
+    def do(self, action, name, args, async=False):
         "Perform action"
         if args.pop('meta', None):
             return (dict(
@@ -176,6 +177,7 @@ class BeaconAPI(object):
             body = kw['params'] = args
         else:
             body = kw['data'] = json.dumps(args, indent=1)
+        if self.timeout: kw['timeout'] = self.timeout
 
 
         headers = {'content-type': 'application/json'}
@@ -189,6 +191,9 @@ class BeaconAPI(object):
             headers['accept'] = 'application/xml'
 
         headers.update(self.headers)
+        if async:
+            import grequests
+            return grequests.AsyncRequest(action, url, headers=headers, **kw)
 
         try:
             r = self.session.request(action, url, verify=True, headers=headers, **kw)
